/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.userupdate.ldap;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.ldap.core.LdapTemplate;
import se.vgregion.userupdate.domain.UnitLdapAttributes;
import se.vgregion.userupdate.domain.UserLdapAttributes;

import java.util.ArrayList;
import java.util.List;

/**
 * Data access object using LDAP.
 *
 * @author <a href="mailto:david.rosell@redpill-linpro.com">David Rosell</a>
 */
@SuppressWarnings("unchecked")
public class UserLdapDao {

    @Autowired
    private LdapTemplate ldapTemplate;

    /**
     * Retrieve {@link UserLdapAttributes}s for a uid.
     *
     * @param uid the uid
     * @return a {@link List} of {@link UserLdapAttributes}
     */
    public List<UserLdapAttributes> resolve(String uid) {
        String base = "ou=anv,o=vgr";
        String filter = String.format("(&(objectClass=person)(uid=%s))", uid);
        return ldapTemplate.search(base, filter, new UserMapper());
    }

    /**
     * Retrieve all {@link UnitLdapAttributes} which are associated with a certain {@link UserLdapAttributes}.
     *
     * @param userLdapAttributes the {@link UserLdapAttributes}
     * @return a {@link List} of {@link UnitLdapAttributes}
     */
    public List<UnitLdapAttributes> resolve(UserLdapAttributes userLdapAttributes) {
        List<UnitLdapAttributes> unitList = new ArrayList<UnitLdapAttributes>();
        if (userLdapAttributes.getVgrStrukturPersonDN() != null) {
            for (String orgDn : userLdapAttributes.getVgrStrukturPersonDN()) {
                Object result = ldapTemplate.lookup(orgDn, new UnitMapper());
                if (result != null && (result instanceof UnitLdapAttributes)) {
                    unitList.add((UnitLdapAttributes) result);
                }
            }
        }
        return unitList;
    }
}
