/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.userupdate.ldap;

import org.springframework.ldap.core.DirContextAdapter;
import org.springframework.ldap.core.simple.ParameterizedContextMapper;
import se.vgregion.userupdate.domain.UserLdapAttributes;

/**
 * Created by IntelliJ IDEA.
 * Created: 2011-11-28 11:05
 *
 * @author <a href="mailto:david.rosell@redpill-linpro.com">David Rosell</a>
 */
public class UserMapper implements ParameterizedContextMapper<UserLdapAttributes> {
    @Override
    public UserLdapAttributes mapFromContext(Object context) {
        DirContextAdapter ctx = (DirContextAdapter) context;

        UserLdapAttributes attrs = new UserLdapAttributes();
        attrs.setDn(ctx.getDn());
        attrs.setUid(ctx.getStringAttribute("uid"));
        attrs.setCn(ctx.getStringAttribute("cn"));
        attrs.setSn(ctx.getStringAttribute("sn"));
        attrs.setGivenName(ctx.getStringAttribute("givenName"));
        attrs.setDisplayName(ctx.getStringAttribute("displayName"));
        attrs.setFullName(ctx.getStringAttribute("fullName"));
        attrs.setMail(ctx.getStringAttribute("mail"));
        attrs.setHsaTitle(ctx.getStringAttribute("hsaTitle"));
        attrs.setTitle(ctx.getStringAttribute("title"));
        attrs.setHsaPersonIdentityNumber(ctx.getStringAttribute("hsaPersonIdentityNumber"));
        attrs.setHsaPersonPrescriptionCode(ctx.getStringAttribute("hsaPersonPrescriptionCode"));
        attrs.setVgrAdminType(ctx.getStringAttribute("vgrAdminType"));
        attrs.setVgrLabeledURI(ctx.getStringAttributes("labeledURI"));
        attrs.setVgrStrukturPerson(ctx.getStringAttributes("vgrStrukturPerson"));
        attrs.setVgrStrukturPersonDN(ctx.getStringAttributes("vgrStrukturPersonDN"));
        attrs.setStrukturGrupp(ctx.getStringAttributes("StrukturGrupp"));

        String type = ctx.getDn().toString();
        if (type.contains("ou=personal")) {
            attrs.setType(UserLdapAttributes.Type.PERSONAL);
        } else if (type.contains("ou=externa")) {
            attrs.setType(UserLdapAttributes.Type.EXTERNA);
        } else if (type.contains("ou=medborgare")) {
            attrs.setType(UserLdapAttributes.Type.MEDBORGARE);
        } else if (type.contains("ou=politiker")) {
            attrs.setType(UserLdapAttributes.Type.POLITIKER);
        } else if (type.contains("ou=admin")) {
            attrs.setType(UserLdapAttributes.Type.TMG);
        } else {
            attrs.setType(UserLdapAttributes.Type.UNKNOWN);
        }

        return attrs;
    }
}
